BEGIN;

-- Fartøy_ID -> Registreringsmerke bryter med BCNF
-- Tillukningen til Fartøy_ID er {Fartøy_ID, Registreringsmerke},
-- altså får vi følgende (som ikke bryter med BCNF):
CREATE TABLE fiskeri.fartøy(
    Fartøy_ID text PRIMARY KEY,
    Registreringsmerke text
);

-- Har nå en tabell med alle attributter bortsett fra Registreringsmerke
-- Tillatelse_kode -> Tillatelse bryter med BCNF
-- Tillukningen til Tillatelse_kode er {Tillatelse_kode, Tillatelse},
-- så får følgende (som ikke bryter BCNF):
CREATE TABLE fiskeri.tillatelsesInfo(
    Tillatelse_kode text PRIMARY KEY,
    Tillatelse text
);

-- Har nå en tabell med alle attributter bortsett fra Registreringsmerke og Tillatelse
-- Tillatelse_ID -> Data_pr bryter med BCNF
-- Tillukningen til Tillatelse_ID er
--   {Tillatelse_ID, Data_pr, Fartøy_ID, Tillatelse_kode,
--    Tillatelse_Gjelder_Fra_Dato, Tillatelse_Gjelder_Til_Dato,
--    Kvotestr_Gjelder_Fra_Dato, Kvotestr_Gjelder_Til_Dato},
-- så får følgende (som ikke bryter BCNF):
CREATE TABLE fiskeri.tillatelse(
    Tillatelse_ID text PRIMARY KEY,
    Data_pr date,
    Fartøy_ID text REFERENCES fiskeri.fartøy(Fartøy_ID),
    Tillatelse_kode text REFERENCES fiskeri.tillatelsesInfo(Tillatelse_kode),
    Tillatelse_gjelder_fra_dato timestamp,
    Tillatelse_gjelder_til_dato timestamp,
    Kvotestr_gjelder_fra_dato timestamp,
    Kvotestr_gjelder_til_dato timestamp
);
    
-- Står nå igjen med følgende tabell, som ikke bryter med BCNF:
CREATE TABLE fiskeri.tillatelsesLinje(
    Tillatelse_ID text REFERENCES fiskeri.tillatelse(Tillatelse_ID),
    Linjenummer int,
    Linjenummer_beskrivelse text,
    Kvotestørrelse float,
    PRIMARY KEY (Tillatelse_ID, Linjenummer)
);

-- Setter så inn data fra fiskeri.kvoter i hver tabell:

INSERT INTO fiskeri.fartøy
SELECT DISTINCT Fartøy_ID, Registreringsmerke
FROM fiskeri.kvoter;

INSERT INTO fiskeri.tillatelsesInfo
SELECT DISTINCT Tillatelse_kode, Tillatelse
FROM fiskeri.kvoter;

INSERT INTO fiskeri.tillatelse
SELECT DISTINCT Tillatelse_ID, Data_pr, Fartøy_ID, Tillatelse_kode,
    Tillatelse_gjelder_fra_dato, Tillatelse_gjelder_til_dato
    Kvotestr_gjelder_fra_dato, Kvotestr_gjelder_til_dato
FROM fiskeri.kvoter;

INSERT INTO fiskeri.tillatelsesLinje
SELECT DISTINCT Tillatelse_ID, Linjenummer, Linjenummer_beskrivelse, Kvotestørrelse
FROM fiskeri.kvoter
WHERE Linjenummer IS NOT NULL; -- Finnes rader i kvoter som mangler linjenummer

COMMIT;
